==> stripe_api-0.1.16-py2.py3-none-any.whl: stripe/customer.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Stripe API
# Copyright (c) 2008-2019 Hive Solutions Lda.
#
# This file is part of Hive Stripe API.
#
# Hive Stripe API is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Stripe API is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Stripe API. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

class CustomerAPI(object):

    def create_customer(self):
        url = self.base_url + "customers"
        contents = self.post(url)
        return contents

    def create_card_customer(
        self,
        customer_id,
        exp_month,
        exp_year,
        number
    ):
        url = self.base_url + "customers/%s/sources" % customer_id
        contents = self.post(
            url,
            params = {
                "source[object]" : "card",
                "source[exp_month]" : exp_month,
                "source[exp_year]" : exp_year,
                "source[number]" : number
            }
        )
        return contents

==> stripe_api-0.3.1-py2.py3-none-any.whl: stripe/customer.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Stripe API
# Copyright (c) 2008-2025 Hive Solutions Lda.
#
# This file is part of Hive Stripe API.
#
# Hive Stripe API is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Stripe API is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Stripe API. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__copyright__ = "Copyright (c) 2008-2025 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """


class CustomerAPI(object):

    def create_customer(self):
        url = self.base_url + "customers"
        contents = self.post(url)
        return contents

    def create_card_customer(self, customer_id, exp_month, exp_year, number):
        url = self.base_url + "customers/%s/sources" % customer_id
        contents = self.post(
            url,
            params={
                "source[object]": "card",
                "source[exp_month]": exp_month,
                "source[exp_year]": exp_year,
                "source[number]": number,
            },
        )
        return contents
